From: NeilBrown <neilb@suse.com>
To: Jens Axboe <axboe@fb.com>
Cc: linux-block@vger.kernel.org, linux-kernel@vger.kernel.org
Subject: [PATCH 1/2] loop: use filp_close() rather than fput()
Date: Fri, 16 Jun 2017 15:02:09 +1000 [thread overview]
Message-ID: <149758932908.10006.10765671892098302463.stgit@noble> (raw)
In-Reply-To: <149758925866.10006.12779875832895865043.stgit@noble>
When a loop device is being shutdown the backing file is
closed with fput(). This is different from how close(2)
closes files - it uses filp_close().
The difference is important for filesystems which provide a ->flush
file operation such as NFS. NFS assumes a flush will always
be called on last close, and gets confused otherwise.
Signed-off-by: NeilBrown <neilb@suse.com>
---
drivers/block/loop.c | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/drivers/block/loop.c b/drivers/block/loop.c
index ebbd0c3fe0ed..9c457ca6c55e 100644
--- a/drivers/block/loop.c
+++ b/drivers/block/loop.c
@@ -682,7 +682,7 @@ static int loop_change_fd(struct loop_device *lo, struct block_device *bdev,
if (error)
goto out_putf;
- fput(old_file);
+ filp_close(old_file, NULL);
if (lo->lo_flags & LO_FLAGS_PARTSCAN)
loop_reread_partitions(lo, bdev);
return 0;
@@ -1071,12 +1071,12 @@ static int loop_clr_fd(struct loop_device *lo)
loop_unprepare_queue(lo);
mutex_unlock(&lo->lo_ctl_mutex);
/*
* Need not hold lo_ctl_mutex to fput backing file.
* Calling fput holding lo_ctl_mutex triggers a circular
* lock dependency possibility warning as fput can take
* bd_mutex which is usually taken before lo_ctl_mutex.
*/
- fput(filp);
+ filp_close(filp, NULL);
return 0;
}
next prev parent reply other threads:[~2017-06-16 5:04 UTC|newest]
Thread overview: 10+ messages / expand[flat|nested] mbox.gz Atom feed top
2017-06-16 5:02 [PATCH 0/2] Two fixes for loop devices NeilBrown
2017-06-16 5:02 ` NeilBrown [this message]
2017-06-16 7:37 ` [PATCH 1/2] loop: use filp_close() rather than fput() Christoph Hellwig
2017-06-17 0:01 ` Al Viro
2017-06-18 4:30 ` NeilBrown
2017-06-16 5:02 ` [PATCH 2/2] loop: Add PF_LESS_THROTTLE to block/loop device thread NeilBrown
2017-06-16 7:36 ` Christoph Hellwig
2017-06-16 14:29 ` [PATCH 0/2] Two fixes for loop devices Jens Axboe
2017-06-18 4:33 ` NeilBrown
2017-06-18 15:06 ` Jens Axboe
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=149758932908.10006.10765671892098302463.stgit@noble \
--to=neilb@suse.com \
--cc=axboe@fb.com \
--cc=linux-block@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1071,12 +1071,12 @@ static int loop_clr_fd(struct loop_device *lo)
mutex_unlock(&lo->lo_ctl_mutex);
/*
- * Need not hold lo_ctl_mutex to fput backing file.
+ * Need not hold lo_ctl_mutex to close backing file.
* Calling fput holding lo_ctl_mutex triggers a circular
* lock dependency possibility warning as fput can take
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox